
from typing import Tuple


class ShapeModel:
    """
    This class is the model of a shape ('view' in an MVC pattern).
    """

    def __init__(self, viewShape=None):
        """
        A model can have many views on different diagram frames

        Args:
            viewShape:  Shape (view) that represents this model
        """
        self._views = []

        if viewShape is not None:
            self._views.append(viewShape)

        self._x: int = 0
        self._y: int = 0

    def GetPosition(self) -> Tuple[int, int]:
        """

        Returns:
            the position of the model
        """
        return self._x, self._y

    def SetPosition(self, x: int, y: int):
        """

        Args:
            x:  abscissa of the model.
            y:  ordinate of the model.

        """
        self._x = x
        self._y = y

    def AddShape(self, viewShape):
        """
        Add the specified Shape (view) to the model
        Args:
            viewShape:
                Shape (view) to add to the model
        """
        self._views.append(viewShape)

    def removeShape(self, viewShape):
        """
        Remove the specified Shape (view) from the model. An exception is
        thrown when the specified Shape doesn't exist.
        Args:
            viewShape:
                Shape (view) to remove from the model
        """
        self._views.remove(viewShape)

    def GetAllViews(self):
        """

        Returns:
            all the shapes (views) attached to this model
        """
        return self._views



from logging import Logger
from logging import getLogger

from wx import WHITE_BRUSH

from miniogl.Shape import Shape

from pyutmodel.PyutLink import PyutLink
from ogl.OglClass import OglClass
from ogl.OglLink import OglLink


class OglInheritance(OglLink):
    """
    Graphical OGL representation of an inheritance link.
    This class provide the methods for drawing an inheritance link between
    two classes of a UML diagram. Add labels to an OglLink.
    """
    def __init__(self, srcShape: OglClass, pyutLink: PyutLink, dstShape: OglClass, srcPos=None, dstPos=None):
        """

        Args:
            srcShape: Source shape
            pyutLink: Conceptual links associated with the graphical links.
            dstShape: Destination shape
            srcPos:   Position of source      Override location of input source
            dstPos:   Position of destination Override location of input destination
        """
        super().__init__(srcShape, pyutLink, dstShape, srcPos=srcPos, dstPos=dstPos)

        self.logger: Logger = getLogger(__name__)
        # Arrow must be white inside
        self.SetBrush(WHITE_BRUSH)
        self.SetDrawArrow(True)

    def __repr__(self):
        srcShape:  Shape = self.sourceShape
        dstShape:  Shape = self.destinationShape
        sourceId:  int   = srcShape.id
        dstId:     int   = dstShape.id
        return f'OglInheritance[from: id: {sourceId} {srcShape} to: id: {dstId} {dstShape}]'
